def calculate_absolute_time(note_blocks):
    absolute_times = []
    prev_absolute_time = 0
    
    for block in note_blocks:
        start_ticks_LSB = int(block[1])
        start_ticks_MSB = int(block[2])
        
        if start_ticks_LSB < 0:
            absolute_time = 255 - abs(start_ticks_LSB) + 1 + start_ticks_MSB * (2 ** 8) + prev_absolute_time
        else:
            absolute_time = start_ticks_LSB + start_ticks_MSB * (2 ** 8) + prev_absolute_time
        
        absolute_times.append(absolute_time)
        prev_absolute_time = absolute_time
    
    return absolute_times


def calculate_duration(note_blocks):
    durations = []
    
    for block in note_blocks:
        dur_ticks_LSB = int(block[6])
        dur_ticks_MSB = int(block[7])
        
        if dur_ticks_LSB < 0:
            duration = 255 - abs(dur_ticks_LSB) + 1 + dur_ticks_MSB * (2 ** 8)
        else:
            duration = dur_ticks_LSB + dur_ticks_MSB * (2 ** 8)
        
        durations.append(duration)
    
    return durations


# Read note block data from file
with open("note_blocks.txt", "r") as file:
    note_blocks_data = file.readlines()

# Parse note block data
note_blocks = [line.strip().split(",") for line in note_blocks_data]

# Calculate absolute timing
absolute_times = calculate_absolute_time(note_blocks)

# Calculate durations
durations = calculate_duration(note_blocks)

# Output debug and final information
with open("console.txt", "w") as console_file, open("xmlvals.txt", "w") as xmlvals_file:
    for i, block in enumerate(note_blocks):
        absolute_time = absolute_times[i]
        duration = durations[i]
        mem_index = i * 8
        console_text = f"MemIdx = {mem_index} - MIDI Note at tick {absolute_time}, channel 1, note {block[3]}, duration {duration}, von {block[4]}, voff {block[5]}\n"
        console_file.write(console_text)

    num_elements = len(note_blocks)
    last_note_abs_time = absolute_times[-1]
    last_note_duration = durations[-1]
    penultimate_note_abs_time = absolute_times[-2]
    penultimate_note_duration = durations[-2]
    xmlvals_text = f"Number of Elements: {num_elements}\n"
    xmlvals_text += f"Last Note: {last_note_abs_time + last_note_duration}\n"
    xmlvals_text += f"Penultimate Note: {penultimate_note_abs_time + penultimate_note_duration}\n"
    xmlvals_file.write(xmlvals_text)
