import sys
import mido

def analyze_midi(filename):
    mid = mido.MidiFile(filename)

    # Open files for writing
    header_file = open("Header.txt", "w")
    notes_file = open("Notes.txt", "w")
    footer_file = open("Footer.txt", "w")

    # MIDI analysis code
    is_note_section = False
    total_time = 0
    for i, track in enumerate(mid.tracks):
        for msg in track:
            if not is_note_section:
                if isinstance(msg, mido.Message) and msg.type == 'note_on':
                    is_note_section = True
                    total_time += msg.time
                    notes_file.write(f"{msg.note},{msg.velocity},{msg.time},{total_time}\n")
                else:
                    header_file.write(str(msg) + "\n")
            elif is_note_section:
                if isinstance(msg, mido.Message) and msg.type == 'note_on':
                    total_time += msg.time
                    notes_file.write(f"{msg.note},{msg.velocity},{msg.time},{total_time}\n")
                elif isinstance(msg, mido.Message) and msg.type == 'note_off':
                    total_time += msg.time
                    notes_file.write(f"{msg.note},0,{msg.time},{total_time}\n")
                else:
                    footer_file.write(str(msg) + "\n")

    # Close files
    header_file.close()
    notes_file.close()
    footer_file.close()

if __name__ == '__main__':
    if len(sys.argv) < 2:
        print("Please provide the MIDI filename as a command-line argument.")
    else:
        midi_filename = sys.argv[1]
        analyze_midi(midi_filename)
